@@ -9,50 +9,54 @@ use 5.008;
 use strict;
 use warnings FATAL => 'all';
 
-use Exporter 5.57 'import';
+use Sub::Exporter;
 use XSLoader ();
-use Carp qw/croak/;
-use Readonly 1.03;
+use Carp qw/croak carp/;
+use Const::Fast;
 use PerlIO ();
 
-our (@EXPORT_OK, %EXPORT_TAGS);
-
 BEGIN {
-	our $VERSION = '0.29';
+	our $VERSION = '0.30';
 
 	XSLoader::load('File::Map', $VERSION);
 }
 
 my %export_data = (
-	'map'  => [qw/map_handle map_file map_anonymous unmap sys_map/],
-	extra  => [qw/remap sync pin unpin advise protect/],
-	'lock' => [qw/wait_until notify broadcast lock_map/],
+	'map'     => [qw/map_handle map_file map_anonymous unmap sys_map/],
+	extra     => [qw/remap sync pin unpin advise protect/],
+	'lock'    => [qw/wait_until notify broadcast lock_map/],
+	constants => [qw/PROT_NONE PROT_READ PROT_WRITE PROT_EXEC MAP_ANONYMOUS MAP_SHARED MAP_PRIVATE MAP_ANON MAP_FILE/]
 );
 
-while (my ($category, $functions) = each %export_data) {
-	for my $function (grep { defined &{$_} } @{$functions}) {
-		push @EXPORT_OK, $function;
-		push @{ $EXPORT_TAGS{$category} }, $function;
+{
+	my (@export_ok, %export_tags);
+
+	while (my ($category, $functions) = each %export_data) {
+		for my $function (grep { defined &{$_} } @{$functions}) {
+			push @export_ok, $function;
+			push @{ $export_tags{$category} }, $function;
+		}
 	}
+
+	Sub::Exporter::setup_exporter({ exports => \@export_ok, groups => \%export_tags });
 }
 
-@{ $EXPORT_TAGS{all} } = @EXPORT_OK;
-
-Readonly our %PROTECTION_FOR => (
+const our %PROTECTION_FOR => (
 	'<'  => PROT_READ,
 	'+<' => PROT_READ | PROT_WRITE,
 	'>'  => PROT_WRITE,
 	'+>' => PROT_READ | PROT_WRITE,
 );
 
-Readonly my $ANON_FH => -1;
+const my $ANON_FH => -1;
 
-Readonly my %is_binary => map { ($_ => 1) } qw/unix stdio perlio mmap crlf/;    # crlf can be binary, this needs a better check
+const my %is_binary => map { ($_ => 1) } qw/unix stdio perlio mmap crlf/;    # crlf can be binary, this needs a better check
 
 sub _check_layers {
 	my $fh = shift;
+	return if not warnings::enabled('layer');
 	for my $layer (PerlIO::get_layers($fh)) {
-		croak "Can't mmap not binary filehandle: layer '$layer' is not binary" if not $is_binary{$layer};
+		carp "Shouldn't mmap non-binary filehandle: layer '$layer' is not binary" if not exists $is_binary{$layer};
 	}
 	return;
 }
@@ -114,7 +118,7 @@ File::Map - Memory mapping made simple and safe.
 
 =head1 VERSION
 
-Version 0.29
+Version 0.30
 
 =head1 SYNOPSIS
 
@@ -350,10 +354,6 @@ A zero length anonymous map is not possible (or in any way useful).
 
 An attempts was made to remap a mapping that is shared among different threads, this is not possible.
 
-=item * Can't mmap not binary filehandle: layer '%s' is not binary
-
-You tried to to map a filehandle that has some encoding layer. This is not supported by File::Map.
-
 =item * Window ($start, $end) is outside the file
 
 The offset and/or length you specified were invalid for this file.
@@ -372,6 +372,10 @@ Due to the way perl works internally, it's not possible to write a mapping imple
 
 This warning is additional to the previous one, warning you that you're losing data. This warning is only given when C<use warnings 'substr'> is in effect.
 
+=item * Shouldn't mmap non-binary filehandle: layer '%s' is not binary
+
+You tried to to map a filehandle that has some encoding layer. Encoding layers are not supported by File::Map. This warning is only given when C<use warnings 'layer'> is in effect.
+
 =item * Unknown advice '%s'
 
 You gave advise an advice it didn't know. This is probably either a typo or a portability issue. This warning is only given when C<use warnings 'portable'> is in effect.
@@ -388,19 +392,19 @@ Overwriting an empty map is rather nonsensical, hence a warning is given when th
 
 =head1 DEPENDENCIES
 
-This module depends on perl 5.8 and L<Readonly>.
+This module depends on perl 5.8 and L<Const::Fast>.
 
 =head1 PITFALLS
 
-On perl versions lower than 5.11.5 many string functions including C<substr> are limited to L<32bit logic|http://rt.perl.org/rt3//Public/Bug/Display.html?id=72784>, even on 64bit architectures. Effectively this means you can't use them on strings bigger than 2GB. If you are working with such large files, I strongly recommend upgrading to 5.12.
+On perl versions before 5.11.5 many string functions including C<substr> are limited to L<32bit logic|http://rt.perl.org/rt3//Public/Bug/Display.html?id=72784>, even on 64bit architectures. Effectively this means you can't use them on strings bigger than 2GB. If you are working with such large files, I strongly recommend upgrading to 5.12.
 
 This module assumes the file is binary data and doesn't do any encoding or newline transformation for you. Most importantly this means that:
 
 =over 2
 
-=item * On Windows, you have to remember to make your filehandles binary before passing them to C<map_handle> or C<sys_map>. They will not accept a C<crlf> filehandle as it would return a different value than reading it normally would. This can be done using open modes or L<binmode>, see L<PerlIO> for more information.
+=item * On Windows, you have to remember to make your filehandles binary before passing them to C<map_handle> or C<sys_map>. It may warn on a filehandle doing C<crlf> transformation as it would return a different value than reading it normally would. This can be remedied by using open modes or L<binmode>, see L<PerlIO> for more information.
 
-=item * You can make it a unicode string in-place by using L<utf8::decode|utf8/"Utility_functions"> if it's valid utf-8, but writing to it requires you to really know what you're doing. Currently C<utf8> filehandles are not accepted, though a future version may deal wit them more gracefully.
+=item * You can make it a unicode string in-place by using L<utf8::decode|utf8/"Utility_functions"> if it's valid utf-8, but writing to it requires you to really know what you're doing. Currently C<utf8> filehandles are not dealt with gracefully, though in a future version that may change.
 
 =back
 
@@ -408,6 +412,8 @@ You probably don't want to use C<E<gt>> as a mode. This does not give you readin
 
 =head1 BUGS AND LIMITATIONS
 
+There is an off-by-one bug in Perl's regexp engine, as explained L<here|http://rt.perl.org/rt3//Public/Bug/Display.html?id=73542>. If the length of the file is an exact multiple of the page size, some regexps can trigger a segmentation fault. This can not be fixed in this module though.
+
 As any piece of software, bugs are likely to exist here. Bug reports are welcome.
 
 Please report any bugs or feature requests to C<bug-file-map at rt.cpan.org>, or through
@@ -420,8 +426,6 @@ automatically be notified of progress on your bug as I make changes.
 
 =item * L<Sys::Mmap>, the original Perl mmap module
 
-=item * L<IPC::Mmap>, another mmap module
-
 =item * L<mmap(2)>, your mmap man page
 
 =item * L<Win32::MMF>
